@@ -4,6 +4,7 @@
 __init__ module to load the exo_k library
 """
 from exo_k.util.user_func import *
+from exo_k.two_stream import two_stream_crisp, two_stream_toon, two_stream_lmdz
 from exo_k.util.radiation import *
 from exo_k.util.interp import gauss_legendre, split_gauss_legendre
 from exo_k.util.cst import *
@@ -19,8 +20,10 @@ from .adatabase import Adatabase
 from .cia_table import Cia_table
 from .ciadatabase import CIAdatabase
 from .hires_spectrum import Hires_spectrum
-from .atm import Atm_profile,Atm
-from .chemistry import EquChemTable
-from .gas_mix import Gas_mix
+from .atm import Atm_profile, Atm
+from .atm_2band import Atm_2band
+#from .atm2 import Atm_profile2, Atm2
+from .chemistry import EquChemTable, InterpolationChemistry
+from .gas_mix import Gas_mix, Known_composite_species
 from .settings import Settings
 from .rayleigh import Rayleigh
