@@ -76,7 +76,7 @@ class Atm_profile(object):
     
     def __init__(self, composition={}, psurf=None, ptop=None, logplay=None, tlay=None,
             Tsurf=None, Tstrat=None, grav=None, Rp=None, Mgas=None, rcp=0.28, Nlay=20,
-            logplev=None, aerosols=None,
+            logplev=None, aerosols={},
             ## old parameters that should be None. THey are left here to catch
             ## exceptions and warn the user that their use is obsolete
             Nlev=None, tlev=None,
@@ -135,6 +135,7 @@ class Atm_profile(object):
             raise RuntimeError('Unknown keyword argument in __init__')
         self.gas_mix = None
         self.set_gas(composition, compute_Mgas=False)
+        self.aerosols = None
         self.set_aerosols(aerosols)
         self.rcp = rcp
         self.logplev = None
@@ -316,8 +317,23 @@ class Atm_profile(object):
 
     def set_aerosols(self, aerosols):
         """Sets the aerosols dictionary
+
+        performs the interlayer averaging so that we only have properties at
+        the middle of radiative layers
         """
-        self.aerosols = Aerosols(aerosols)
+        for aer, [reff, densities] in aerosols.items():
+            if isinstance(reff,(np.ndarray, list)):
+                tmp_reff=np.array(reff)
+                aerosols[aer][0]=0.5*(tmp_reff[1:]+tmp_reff[:-1])
+            if isinstance(densities,(np.ndarray, list)):
+                tmp_densities=np.array(densities)
+                #geometrical average:
+                aerosols[aer][1]=np.sqrt(tmp_densities[1:]*tmp_densities[:-1])
+        if self.aerosols is None:
+            self.aerosols = Aerosols(aerosols)
+        else:
+            self.aerosols.set_aer_reffs_densities(aer_reffs_densities=aerosols)
+
 
     def set_Rp(self, Rp):
         """Sets the radius of the planet
@@ -588,7 +604,10 @@ class Atm(Atm_profile):
                 kdata_scat_tot = np.zeros(shape[0:2], dtype=np.float)
             if self.aerosols.adatabase is not None:
                 kdata_scat_tot += k_scat_aer
-                self.asym_param = k_scat_aer * g_aer / kdata_scat_tot
+                self.asym_param = np.where(kdata_scat_tot<=0., 0., k_scat_aer * g_aer / kdata_scat_tot)
+                #the line below is for test. Should be removed
+                #self.asym_param = np.zeros(shape[0:2], dtype=np.float)
+                self.asym_param = np.ones(shape[0:2], dtype=np.float)
             else:
                 self.asym_param = np.zeros(shape[0:2], dtype=np.float)
 
@@ -599,7 +618,8 @@ class Atm(Atm_profile):
                 self.asym_param = self.asym_param[:,:,None] * np.ones(self.Ng)
                 #JL21 the line above could be removed as asym param does not seem to change
                 # with g point, but then the dimensions should be change in 2stream routines.
-            self.single_scat_albedo=np.core.umath.minimum(self.single_scat_albedo,0.9999999999999)
+            self.single_scat_albedo=np.core.umath.minimum(self.single_scat_albedo,0.9999999999)
+            #self.single_scat_albedo=np.core.umath.maximum(self.single_scat_albedo,0.1)
 
         self.Nw=self.gas_mix.Nw
         self.wns=self.gas_mix.wns
@@ -794,6 +814,7 @@ class Atm(Atm_profile):
         # mu_eff=1. because the mu effect is taken into account in solve_2stream_nu
                  # we must compute the vertical optical depth here.
         # JL21: shouldn't we remove flux_top_dw, it seems not to be used.
+        self.single_scat_albedo=np.where(self.dtau<dtau_min,0.,self.single_scat_albedo)
         self.dtau=np.where(self.dtau<dtau_min,dtau_min,self.dtau)
 
         module_to_use=globals()[method]
@@ -870,7 +891,7 @@ class Atm(Atm_profile):
         H[:-1] -= H[1:]
         H[-1] += self.internal_flux
         if per_unit_mass: H *= self.inv_dmass
-        if compute_kernel: self.H_kernel = H
+        #if compute_kernel: self.H_kernel = H
         return H, net
 
     def heating_rate(self, compute_kernel=False, dTmax_use_kernel=None, **kwargs):
@@ -879,16 +900,17 @@ class Atm(Atm_profile):
             if np.amax(np.abs(dT)) < dTmax_use_kernel:
                 try:
                     H = self.H_kernel + np.dot(dT,self.kernel)
+                    net = self.internal_flux - np.cumsum((H*self.dmass)[::-1])[::-1]
                 except:
                     raise RuntimeError("Kernel has not been precomputed")
-                net = np.zeros_like(H)
                 return H, net
         _ = self.emission_spectrum_2stream(flux_at_level=True, integral=True,
                 compute_kernel=compute_kernel, **kwargs)
         H, net = self.flux_divergence(compute_kernel=compute_kernel, **kwargs)
         if compute_kernel:
             self.H_kernel = H
-            self.tau_rad = 1./np.amax(np.abs(self.kernel.diagonal()))
+            self.tau_rads = 1./np.abs(self.kernel.diagonal())
+            self.tau_rad = np.amin(self.tau_rads)
         return H, net
 
 
