@@ -130,12 +130,6 @@ class Ktable(Ktable_io):
             kdata_unit=kdata_unit, file_kdata_unit=file_kdata_unit,
             remove_zeros=remove_zeros)
 
-    @property
-    def shape(self):
-        """Returns the shape of self.kdata
-        """
-        return np.array([self.Np,self.Nt,self.Nw,self.Ng])
-
     def xtable_to_ktable(self, xtable=None, wnedges=None, weights=None, ggrid=None,
         quad='legendre', order=20, g_split=0.9, mid_dw=True, write=0, remove_zeros=False):
         """Fills the :class:`~exo_k.ktable.Ktable` object with a k-coeff table computed
@@ -345,7 +339,7 @@ class Ktable(Ktable_io):
 
             spec_hr=Hires_spectrum(fname, file_kdata_unit=file_kdata_unit,
                 **select_kwargs(kwargs,['skiprows','wn_column','mult_factor',
-                    'kdata_column','data_type']))
+                    'kdata_column','data_type','binary','mass_amu']))
             # for later conversion, the real kdata_unit is in spec_hr.kdata_unit
             self.kdata_unit=spec_hr.kdata_unit
             was_xsec=(spec_hr.data_type=='xsec')
