@@ -80,12 +80,6 @@ class Ktable5d(Data_table):
         if self.kdata is not None:
             self.setup_interpolation()
 
-    @property
-    def shape(self):
-        """Returns the shape of self.kdata
-        """
-        return np.array([self.Np,self.Nt,self.Nx,self.Nw,self.Ng])
-
     def read_hdf5(self, filename=None, mol=None):
         """Initializes k coeff table and supporting data from an Exomol hdf5 file
 
@@ -132,7 +126,8 @@ class Ktable5d(Data_table):
             if 'weights' in f.keys():
                 self.weights=f['weights'][...]
             else:
-                raise RuntimeError('No weights keyword. This file is probably a cross section file.')
+                raise RuntimeError("""No weights keyword.
+                    This file is probably a cross section file.""")
             self.ggrid=f['samples'][...]
             self.gedges=np.insert(np.cumsum(self.weights),0,0.)
             self.logk=False
@@ -391,7 +386,7 @@ class Ktable5d(Data_table):
 
                 spec_hr=Hires_spectrum(fname, file_kdata_unit=file_kdata_unit,
                     **select_kwargs(kwargs,['skiprows','wn_column','mult_factor',
-                        'kdata_column','data_type']))
+                        'kdata_column','data_type','binary','mass_amu']))
                 # for later conversion, the real kdata_unit is in spec_hr.kdata_unit
                 self.kdata_unit=spec_hr.kdata_unit
                 was_xsec=(spec_hr.data_type=='xsec')
@@ -437,7 +432,7 @@ class Ktable5d(Data_table):
                 bounds_error=True)
         else:
             self._finterp_kdata=RegularGridInterpolator( \
-                (self.logpgrid,self.tgrid,np.log(self.xgrid)), self.kdata, \
+                (self.logpgrid, self.tgrid, self.xgrid), self.kdata, \
                 bounds_error=True)
 
     def set_kdata(self, new_kdata):
@@ -449,11 +444,11 @@ class Ktable5d(Data_table):
             new_kdata: array
                 New array of kdata.
         """
-        self.kdata=new_kdata
+        super().set_kdata(new_kdata)
         self.setup_interpolation()
 
     def interpolate_kdata(self, logp_array=None, t_array=None, x_array= None,
-            log_interp=None, wngrid_limit=None):
+            log_interp=None, logp_interp=True, wngrid_limit=None, **kwargs):
         """interpolate_kdata interpolates the kdata at on a given temperature and
         log pressure profile. 
 
@@ -480,11 +475,13 @@ class Ktable5d(Data_table):
                 The interpolated kdata.
         """
         #clipping data
+        if not logp_interp:
+            raise RuntimeError('Linear p interpolation not yet supported for Ktable5d.')
+        if log_interp != self._local_log_interp:
+            self.setup_interpolation(log_interp=log_interp)
         logp_array=np.clip(logp_array, self.logpgrid[0], self.logpgrid[-1])
         t_array=np.clip(t_array, self.tgrid[0], self.tgrid[-1])
         x_array=np.clip(x_array, self.xgrid[0], self.xgrid[-1])
-        coord_to_interp=np.array([logp_array,t_array,np.log(x_array)]).transpose()
-        tmp_res=self._finterp_kdata(coord_to_interp)
         if wngrid_limit is None:
             wngrid_filter = slice(None)
         else:
@@ -492,14 +489,19 @@ class Ktable5d(Data_table):
             wngrid_filter = np.where((self.wnedges > wngrid_limit.min()) & (
                 self.wnedges <= wngrid_limit.max()))[0][:-1]
         if self._local_log_interp:
+            coord_to_interp=np.array([logp_array,t_array,np.log(x_array)]).transpose()
+            tmp_res=self._finterp_kdata(coord_to_interp)
             return np.exp(tmp_res[:,wngrid_filter])
         else:
+            coord_to_interp=np.array([logp_array,t_array,x_array]).transpose()
+            tmp_res=self._finterp_kdata(coord_to_interp)
             return tmp_res[:,wngrid_filter]
 
 
     def remap_logPT(self, logp_array=None, t_array=None, x_array= None):
         """remap_logPT re-interpolates the kdata on a new temprature and log pressure grid
-        (inplace). 
+        (inplace). If an `x_array` is specified, the interpolation occurs along the 
+        vmr axis as well. 
 
         Parameters
         ----------
@@ -510,28 +512,39 @@ class Ktable5d(Data_table):
             x_array: Array
                 vmr of variable gas array to interpolate to
 
-        Whether the interpolation is linear in kdata or in log(kdata)
-        is controlled by self._settings._log_interp but only when the ktable is loaded.
-        If you change that after the loading, you should rerun setup_interpolation().
+        .. warning::
+            Whether the interpolation is linear in kdata or in log(kdata)
+            is controlled by self._settings._log_interp but only when the ktable is loaded.
+            If you change that after the loading, you should rerun setup_interpolation().
         """
         #clipping data
-        logp_array=np.clip(logp_array, self.logpgrid[0], self.logpgrid[-1])
-        t_array=np.clip(t_array, self.tgrid[0], self.tgrid[-1])
-        x_array=np.clip(x_array, self.xgrid[0], self.xgrid[-1])
-        coord=np.array(np.meshgrid(logp_array, t_array, np.log(x_array))).transpose((2,1,3,0))
+        logp_array_tmp=np.clip(logp_array, self.logpgrid[0], self.logpgrid[-1])
+        t_array_tmp=np.clip(t_array, self.tgrid[0], self.tgrid[-1])
+        if x_array is None:
+            x_array_tmp=self.xgrid
+            #it is a bit silly to interpolate on x anyway, even when the user
+            # only wants to remap on P and T, but it is
+            # way simpler to write!
+        else:
+            x_array_tmp=np.clip(x_array, self.xgrid[0], self.xgrid[-1])
         if self._local_log_interp:
+            coord=np.array(np.meshgrid(
+                logp_array_tmp, t_array_tmp, np.log(x_array_tmp))).transpose((2,1,3,0))
             tmp_res=np.exp(self._finterp_kdata(coord))
         else:
+            coord=np.array(np.meshgrid(
+                logp_array_tmp, t_array_tmp, x_array_tmp)).transpose((2,1,3,0))
             tmp_res=self._finterp_kdata(coord)
         self.logpgrid= logp_array
         self.pgrid   = 10**self.logpgrid
-        self.tgrid   = t_array
-        self.xgrid   = x_array
         self.Np      = logp_array.size
+        self.tgrid   = t_array
         self.Nt      = t_array.size
-        self.Nx      = x_array.size
+        if x_array is not None:
+            self.xgrid   = x_array
+            self.Nx      = x_array.size
         self.set_kdata(tmp_res)
-        self.setup_interpolation()
+#        self.setup_interpolation()
 
     def copy(self,cp_kdata=True):
         """Creates a new instance of :class:`Ktable5d` object and (deep) copies data into it
